@@ -94,15 +94,14 @@ namespace acommon {
 
   class Convert {
   private:
-    CachePtr<Decode> decode_d;
+    CachePtr<Decode> decode_c;
+    StackPtr<Decode> decode_s;
     Decode * decode_;
-    CachePtr<Encode> encode_d;
+    CachePtr<Encode> encode_c;
+    StackPtr<Encode> encode_s;
     Encode * encode_;
     CachePtr<NormTables> norm_tables_;
-    DirectConv * conv_;
-
-    static const size_t memory_size = 96;
-    char memory[memory_size];
+    StackPtr<DirectConv> conv_;
 
     ConvertBuffer buf_;
 
@@ -113,6 +112,7 @@ namespace acommon {
 
   public:
     Convert() {}
+    ~Convert();
 
     // This filter is used when the convert method is called.  It must
     // be set up by an external entity as this class does not set up
@@ -266,8 +266,7 @@ namespace acommon {
       if (conv) {
         buf.clear();
         conv->convert(str, sz, buf, buf0);
-        buf.ensure_null_end();
-        return buf.data();
+        return buf.mstr();
       } else {
         return str;
       }
@@ -291,8 +290,7 @@ namespace acommon {
       if (conv) {
         buf.clear();
         conv->convert(str, -1, buf, buf0);
-        buf.ensure_null_end();
-        return buf.data();
+        return buf.mstr();
       } else {
         return str;
       }
@@ -302,13 +300,12 @@ namespace acommon {
       if (conv) {
         buf.clear();
         conv->convert(str, -1, buf, buf0);
-        buf.ensure_null_end();
-        return buf.data();
+        return buf.mstr();
       } else {
         return str;
       }
     }
-    const char * operator() (char c)
+    char * operator() (char c)
     {
       buf.clear();
       if (conv) {
@@ -317,8 +314,7 @@ namespace acommon {
       } else {
         buf.append(c);
       }
-      buf.ensure_null_end();
-      return buf.data();
+      return buf.mstr();
     }
   };
 
@@ -357,8 +353,7 @@ namespace acommon {
       if (conv) {
         buf.clear();
         RET_ON_ERR(conv->convert_ec(str, sz, buf, buf0, str));
-        buf.ensure_null_end();
-        return buf.data();
+        return buf.mstr();
       } else {
         return str;
       }
@@ -372,8 +367,7 @@ namespace acommon {
       if (conv) {
         buf.clear();
         RET_ON_ERR(conv->convert_ec(str, -1, buf, buf0, str));
-        buf.ensure_null_end();
-        return buf.data();
+        return buf.mstr();
       } else {
         return str;
       }
@@ -384,8 +378,7 @@ namespace acommon {
       if (conv) {
         buf.clear();
         RET_ON_ERR(conv->convert_ec(str, -1, buf, buf0, str));
-        buf.ensure_null_end();
-        return buf.data();
+        return buf.mstr();
       } else {
         return str.str();
       }
